@@ -31,9 +31,11 @@
 */
 
 typedef enum {
-  CBCGEN_TEST_MSG = 1,
-  CBCGEN_NEW_SOLVER,
-  CBCGEN_CONFUSION,
-  CBCGEN_DUMMY_END } CbcGenMsgCode ;
+    CBCGEN_TEST_MSG = 1,
+    CBCGEN_NEW_SOLVER,
+    CBCGEN_CONFUSION,
+    CBCGEN_DUMMY_END
+} CbcGenMsgCode ;
 
 #endif
+
